==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lt/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Vartotojas svetainėje atšaukė elemento užklausą',
    'a_user_requested' => 'Vartotojas paprašė elemento svetainėje',
    'accessory_name' => 'Aksesuaro pavadinimas:',
    'additional_notes' => 'Papildomi komentarai:',
    'admin_has_created' => 'Administratorius sukūrė jums sąskaitą: interneto svetainėje.',
    'asset' => 'Įranga:',
    'asset_name' => 'Įrangos pavadinimas:',
    'asset_requested' => 'Užklausta įranga',
    'asset_tag' => 'Įrangos nr:',
    'assigned_to' => 'Priskirtas',
    'best_regards' => 'pagarbiai,',
    'canceled' => 'Atšauktas:',
    'checkin_date' => 'Priėmimo data:',
    'checkout_date' => 'Užsakymo data:',
    'click_to_confirm' => 'Spustelėkite šią nuorodą norėdami patvirtinti savo: interneto paskyra:',
    'click_on_the_link_accessory' => 'Spustelėkite nuorodą apačioje, kad patvirtintumėte, jog gavote priedą.',
    'click_on_the_link_asset' => 'Jei norite patvirtinti, kad gavote turtą, spustelėkite saitą apačioje.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Esamas kiekis',
    'Days' => 'Dienos',
    'days' => 'Dienos',
    'expecting_checkin_date' => 'Numatyta priėmimo data:',
    'expires' => 'Galiojimo laikas',
    'Expiring_Assets_Report' => 'Galiojanti turto ataskaita.',
    'Expiring_Licenses_Report' => 'Galiojanti licencijų ataskaita.',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Aš perskaičiau ir sutinku su naudojimo sąlygomis ir gavau šį elementą.',
    'item' => 'Įranga:',
    'Item_Request_Canceled' => 'Prekės užklausa atšaukta',
    'Item_Requested' => 'Įranga užklausta',
    'link_to_update_password' => 'Jei norite atnaujinti savo slaptažodį, spustelėkite šią nuorodą:',
    'login_first_admin' => 'Prisijunkite prie savo naujojo "Snipe-IT" diegimo naudodami toliau nurodytus įgaliojimus:',
    'login' => 'Prisijungti:',
    'Low_Inventory_Report' => 'Mažos inventorizacijos ataskaita',
    'min_QTY' => 'Min Kiekis',
    'name' => 'Pavadinimas',
    'new_item_checked' => 'Naujas objektas buvo patikrintas pagal jūsų vardą, išsami informacija pateikiama žemiau.',
    'password' => 'Slaptažodis:',
    'password_reset' => 'Slaptažodžio atstatymas',

    'read_the_terms' => 'Prašome perskaityti toliau pateiktas naudojimo sąlygas.',
    'read_the_terms_and_click' => 'Perskaitykite žemiau esančias naudojimo sąlygas ir spustelėkite apačioje esančią nuorodą, kad patvirtintumėte, jog perskaitėte ir sutinkate su naudojimo sąlygomis ir gavote turtą.',
    'requested' => 'Užklausta:',
    'reset_link' => 'Jūsų slaptažodžio atstatymo nuoroda',
    'reset_password' => 'Paspauskite norėdami pakeisti savo slaptažodį:',
    'serial' => 'Serija',
    'supplier' => 'Tiekėjas',
    'tag' => 'Žymė',
    'test_email' => 'Išbandykite "Snipe-IT" el. Laišką',
    'test_mail_text' => 'Tai yra "Snipe-IT Asset Management System" testas. Jei tai gavote, paštas dirba :)',
    'the_following_item' => 'Šis elementas buvo pažymėtas:',
    'low_inventory_alert' => 'Tai yra reikšmė minimalaus inventoriaus arba greitai pasibaigiančio.:count | Tai yra reikšmė minimalaus inventoriaus arba greitai pasibaigiančio.:count.',
    'assets_warrantee_alert' => 'Tiek turto :count kurių garantinis aptarnavimas baigsis už :threshold days.|Tiek turto :count kurių garantinis aptarnavimas baigsis už :threshold days.',
    'license_expiring_alert' => 'Tiek licenzijų :count baigsis už :threshold days.|Tiek licenzijų :count baigsis už :threshold days.',
    'to_reset' => 'Jei norite iš naujo nustatyti savo: žiniatinklio slaptažodį, užpildykite šią formą:',
    'type' => 'Tipas',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Vartotojas',
    'username' => 'Vartotojo vardas',
    'welcome' => 'Sveiki :vardas',
    'welcome_to' => 'Sveiki atvykę į: internetą!',
    'your_credentials' => 'Jūsų Snipe-IT įgaliojimai',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lt/mail.php <==
<?php

return [
    'a_user_canceled' => 'Vartotojas svetainėje atšaukė elemento užklausą',
    'a_user_requested' => 'Vartotojas paprašė elemento svetainėje',
    'accessory_name' => 'Aksesuaro pavadinimas:',
    'additional_notes' => 'Papildomi komentarai:',
    'admin_has_created' => 'Administratorius sukūrė jums sąskaitą: interneto svetainėje.',
    'asset' => 'Įranga:',
    'asset_name' => 'Įrangos pavadinimas:',
    'asset_requested' => 'Užklausta įranga',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Priskirtas',
    'best_regards' => 'pagarbiai,',
    'canceled' => 'Atšauktas:',
    'checkin_date' => 'Priėmimo data:',
    'checkout_date' => 'Užsakymo data:',
    'click_to_confirm' => 'Spustelėkite šią nuorodą norėdami patvirtinti savo: interneto paskyra:',
    'click_on_the_link_accessory' => 'Spustelėkite nuorodą apačioje, kad patvirtintumėte, jog gavote priedą.',
    'click_on_the_link_asset' => 'Jei norite patvirtinti, kad gavote turtą, spustelėkite saitą apačioje.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Esamas kiekis',
    'Days' => 'Dienos',
    'days' => 'Dienos',
    'expecting_checkin_date' => 'Numatyta priėmimo data:',
    'expires' => 'Galiojimo laikas',
    'Expiring_Assets_Report' => 'Galiojanti turto ataskaita.',
    'Expiring_Licenses_Report' => 'Galiojanti licencijų ataskaita.',
    'hello' => 'Sveiki',
    'hi' => 'Sveiki',
    'i_have_read' => 'Aš perskaičiau ir sutinku su naudojimo sąlygomis ir gavau šį elementą.',
    'item' => 'Įranga:',
    'Item_Request_Canceled' => 'Prekės užklausa atšaukta',
    'Item_Requested' => 'Įranga užklausta',
    'link_to_update_password' => 'Jei norite atnaujinti savo slaptažodį, spustelėkite šią nuorodą:',
    'login_first_admin' => 'Prisijunkite prie savo naujojo "Snipe-IT" diegimo naudodami toliau nurodytus įgaliojimus:',
    'login' => 'Prisijungti:',
    'Low_Inventory_Report' => 'Mažos inventorizacijos ataskaita',
    'min_QTY' => 'Min Kiekis',
    'name' => 'Pavadinimas',
    'new_item_checked' => 'Naujas objektas buvo patikrintas pagal jūsų vardą, išsami informacija pateikiama žemiau.',
    'password' => 'Slaptažodis:',
    'password_reset' => 'Slaptažodžio atstatymas',

    'read_the_terms' => 'Prašome perskaityti toliau pateiktas naudojimo sąlygas.',
    'read_the_terms_and_click' => 'Perskaitykite žemiau esančias naudojimo sąlygas ir spustelėkite apačioje esančią nuorodą, kad patvirtintumėte, jog perskaitėte ir sutinkate su naudojimo sąlygomis ir gavote turtą.',
    'requested' => 'Užklausta:',
    'reset_link' => 'Jūsų slaptažodžio atstatymo nuoroda',
    'reset_password' => 'Paspauskite norėdami pakeisti savo slaptažodį:',
    'serial' => 'Serija',
    'supplier' => 'Tiekėjas',
    'tag' => 'Žymė',
    'test_email' => 'Išbandykite "Snipe-IT" el. Laišką',
    'test_mail_text' => 'Tai yra "Snipe-IT Asset Management System" testas. Jei tai gavote, paštas dirba :)',
    'the_following_item' => 'Šis elementas buvo pažymėtas:',
    'low_inventory_alert' => 'Tai yra reikšmė minimalaus inventoriaus arba greitai pasibaigiančio.:count | Tai yra reikšmė minimalaus inventoriaus arba greitai pasibaigiančio.:count.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Tiek licenzijų :count baigsis už :threshold days.|Tiek licenzijų :count baigsis už :threshold days.',
    'to_reset' => 'Jei norite iš naujo nustatyti savo: žiniatinklio slaptažodį, užpildykite šią formą:',
    'type' => 'Tipas',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Vartotojas',
    'username' => 'Vartotojo vardas',
    'welcome' => 'Sveiki :vardas',
    'welcome_to' => 'Sveiki atvykę į: internetą!',
    'your_credentials' => 'Jūsų Snipe-IT įgaliojimai',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
